--[[
ComboPointsRedux_Options - LoD option module for ComboPointsRedux
Author: Michael Joseph Murray aka Lyte of Lothar(US)
$Revision: 98 $
$Date: 2010-07-20 22:30:05 +0000 (Tue, 20 Jul 2010) $
Project Version: r102
contact: codemaster2010 AT gmail DOT com

Copyright (c) 2007-2010 Michael J. Murray aka Lyte of Lothar(US)
All rights reserved unless otherwise explicitly stated.
]]

local core = LibStub("AceAddon-3.0"):GetAddon("ComboPointsRedux")
local L = LibStub("AceLocale-3.0"):GetLocale("ComboPointsRedux")

local opts = {
	type = 'group',
	args = {
	
	},
}

--generate the Core options
opts.args["core"] = {
	type = "group",
	name = "Core",
	order = 1,
	args = {
		locked = {
			type = "toggle",
			name = L["Lock"],
			desc = L["Lock all the frames in place, preventing movement and hiding the background."],
			descStyle = "inline",
			width = "full",
			order = 1,
			get = function() return core.db.profile.locked end,
			set = function()
				core.db.profile.locked = not core.db.profile.locked
				for name, module in core:IterateModules() do
					if module:IsEnabled() then
						if not core.db.profile.locked then
							module.graphics:SetBackdropColor(1,1,1,1)
							module.graphics:EnableMouse(true)
							module.graphics:SetMovable(true)
							module.graphics.points[1]:Show()
							module.graphics.points[2]:Show()
							
							module.text:SetBackdropColor(1,1,1,1)
							module.text:EnableMouse(true)
							module.text:SetMovable(true)
							module.text.count:SetText(module.abbrev)
						else
							module.graphics:EnableMouse(false)
							module.graphics:SetMovable(false)
							module.graphics:SetBackdropColor(1,1,1,0)
							module.graphics.points[1]:Hide()
							module.graphics.points[2]:Hide()
							
							module.text:EnableMouse(false)
							module.text:SetMovable(false)
							module.text:SetBackdropColor(1,1,1,0)
							module.text.count:SetText("")
						end
					end
				end
			end,
		},
	},
}

--generate the enable/disable options per module
for name, module in core:IterateModules() do
	opts.args.core.args[name.."toggle"] = {
		type = "toggle",
		name = format(L["%s Module enabled"], name),
		desc = format(L["Select whether or not the %s module is enabled."], name),
		descStyle = "inline",
		width = "full",
		order = 2,
		get = function()
			return core.db.profile.modules[name].enabled
		end,
		set = function(info, value)
			core.db.profile.modules[name].enabled = value
			if value then
				module:Enable()
			else
				module:Disable()
			end
		end,
	}
end

--generate options for each registered module
local i = 2
for name, module in core:IterateModules() do
	opts.args[name] = {
		type = "group",
		name = name,
		handler = module,
		disabled = function() return not core.db.profile.modules[name].enabled end,
		order = i,
		args = {
			disablegraphics = {
				type = "toggle",
				name = L["Disable Graphics"],
				desc = L["Select whether or not to show this module's graphics."],
				descStyle = "inline",
				width = "full",
				arg = "disableGraphics",
				get = "Get",
				set = function(info, value)
					core.db.profile.modules[name].disableGraphics = value
					if value then
						module.graphics:Hide()
					else
						module.graphics:Show()
					end
				end,
				order = 1,
			},
			disabletext = {
				type = "toggle",
				name = L["Disable Text"],
				desc = L["Select whether or not to show this module's text counter."],
				descStyle = "inline",
				width = "full",
				arg = "disableText",
				get = "Get",
				set = function(info, value)
					core.db.profile.modules[name].disableText = value
					if value then
						module.text:Hide()
					else
						module.text:Show()
					end
				end,
				order = 2,
			},
			graphics = {
				type = "group",
				name = L["%s Graphics"]:format(name),
				inline = true,
				order = 3,
				disabled = function() return core.db.profile.modules[name].disableGraphics end,
				args = {
					onecolor = {
						type = 'color',
						name = L["One Point Color"],
						desc = L["Set the color to be used when you have one 'point' to display."],
						arg = "oneColor",
						get = "Get",
						set = "Set",
						order = 1,
					},
					twocolor = {
						type = 'color',
						name = L["Two Points Color"],
						desc = L["Set the color to be used when you have two 'points' to display."],
						arg = "twoColor",
						get = "Get",
						set = "Set",
						order = 2,
					},
					threecolor = {
						type = 'color',
						name = L["Three Points Color"],
						desc = L["Set the color to be used when you have three 'points' to display."],
						arg = "threeColor",
						get = "Get",
						set = "Set",
						order = 3,
					},
					fourcolor = {
						type = 'color',
						name = L["Four Points Color"],
						desc = L["Set the color to be used when you have four 'points' to display."],
						arg = "fourColor",
						get = "Get",
						set = "Set",
						order = 4,
					},
					fivecolor = {
						type = 'color',
						name = L["Five Points Color"],
						desc = L["Set the color to be used when you have five 'points' to display."],
						arg = "fiveColor",
						get = "Get",
						set = "Set",
						order = 5,
					},
					icon = {
						type = "select",
						name = L["Icon"],
						desc = L["Select the icon to be used for these graphics."],
						arg = "icon",
						get = "Get",
						set = "Set",
						values = { square = L["Square"], circle = L["Circle"], diamond = L["Diamond"] },
						order = 6,
					},
					orientation = {
						type = "select",
						name = L["Orientation"],
						desc = L["Select the orientation of the graphical display (horizontal or vertical)."],
						arg = "orientation",
						get = "Get",
						set = "Set",
						values = { h = L["Horizontal"], v = L["Vertical"] },
						order = 7,
					},
					strata = {
						type = 'select',
						name = L["Graphics Strata"],
						desc = L["Set the strata level of the graphics frame."],
						get = "Get",
						set = "Set",
						arg = "strata",
						values = {["FULLSCREEN"] = "Fullscreen", ["HIGH"] = "High", ["MEDIUM"] = "Medium", ["LOW"] = "Low", ["BACKGROUND"] = "Background",},
						order = 8,
					},
					alpha = {
						type = 'range',
						name = L["Icon Alpha"],
						desc = L["Set the alpha of the icons."],
						arg = "alpha",
						get = "Get",
						set = "Set",
						min = 0.0,
						max = 1.0,
						step = 0.01,
						order = 9,
					},
					scale = {
						type = 'range',
						name = L["Scale"],
						desc = L["Set the scale of the icons."],
						arg = "scale",
						get = "Get",
						set = "Set",
						min = 0.1,
						max = 1.5,
						step = 0.01,
						order = 10,
					},
					spacing = {
						type = 'range',
						name = L["Icon Spacing"],
						desc = L["Set the spacing between the icons."],
						arg = "spacing",
						get = "Get",
						set = "Set",
						min = -2,
						max = 10,
						step = 1,
						order = 11,
					},
				},
			},
			text = {
				type = "group",
				name = L["%s Text"]:format(name),
				inline = true,
				order = 4,
				disabled = function() return core.db.profile.modules[name].disableText end,
				args = {
					font = {
						type = 'select',
						name = L["Font"],
						desc = L["Select the font for the text display."],
						arg = "font",
						get = "Get",
						set = "Set",
						dialogControl = "LSM30_Font",
						values = AceGUIWidgetLSMlists.font,
						order = 1,
					},
					fontsize = {
						type = 'range',
						name = L["Font Size"],
						desc = L["Set the font size for the text display."],
						arg = "fontsize",
						get = "Get",
						set = "Set",
						min = 1,
						max = 36,
						step = 1,
						order = 2,
					},
					textcolor = {
						type = 'color',
						name = L["Text Color"],
						desc = L["Set the color for the text display."],
						arg = "textColor",
						get = "Get",
						set = "Set",
						order = 3,
					},
					textalpha = {
						type = 'range',
						name = L["Text Alpha"],
						desc = L["Set the alpha of the text display."],
						arg = "textAlpha",
						get = "Get",
						set = "Set",
						min = 0.0,
						max = 1.0,
						step = 0.01,
						order = 4,
					},
					textstrata = {
						type = 'select',
						name = L["Text Strata"],
						desc = L["Set the strata level of the text frame."],
						get = "Get",
						set = "Set",
						arg = "textStrata",
						values = {["FULLSCREEN"] = "Fullscreen", ["HIGH"] = "High", ["MEDIUM"] = "Medium", ["LOW"] = "Low", ["BACKGROUND"] = "Background",},
						order = 5,
					},
				},
			},
		},
	}
	
	i = i + 1
end

--add profile controls
opts.args.profile = LibStub("AceDBOptions-3.0"):GetOptionsTable(core.db)

LibStub("AceConfig-3.0"):RegisterOptionsTable("ComboPointsRedux", opts)
LibStub("AceConfigDialog-3.0"):SetDefaultSize("ComboPointsRedux", 800, 500)
--LibStub("AceConfigDialog-3.0"):AddToBlizOptions("ComboPointsRedux", "ComboPointsRedux")
